@@ -547,7 +547,7 @@ console.log(`%cCreated using n4s, by: \nhttps://www.mafshari.work`, 'color:light
         return
 
 ## DOWNLOAD FILES
-def download(URL: str, Filename: str='', Save_Directory: Path=fs.root('downloads'), debug: bool=False):
+def download(URL: str, Filename: str='', Save_Directory: Path=fs.root('downloads'), Detect_Format: bool=True, debug: bool=False):
   '''
   URL: (str) to file or (list) of strings to files
   Filename: Save As... (leave blank to inherit original filename)
@@ -616,7 +616,7 @@ def download(URL: str, Filename: str='', Save_Directory: Path=fs.root('downloads
       Filename = str(URL).split("/")[-1]
     
     ## IF FILENAME ENTERED, BUT NO EXTENSION SPECIFIED - GET EXTENSION FROM ORIGINAL FILE
-    if not '.' in Filename:
+    if not '.' in Filename and Detect_Format:
       Filename = f"{Filename}{file_format}"
 
     ## SAVE FILE TO CHOSEN DIRECTORY
@@ -627,16 +627,17 @@ def download(URL: str, Filename: str='', Save_Directory: Path=fs.root('downloads
       print(f'Done: {Save_Directory}/{Filename}')
 
 ## MERGE HTML/CSS/JS INTO ONE HTML FILE
-def merge_html(HTML: Path, CSS: Path, JS: Path, onefile: bool=False, debug: bool=False, filename: str='index'):
+def merge_html(HTML: Path, CSS: Path, JS: Path, onefile: bool=False, debug: bool=False, filename: str='index', remove_webfiles: bool=False):
         '''
         ARGUMENTS
 
-        - HTML: Path to HTML file
-        - CSS: Path to CSS file
-        - JS: Path to JS file
-        - onefile: Only keep output file (bool)
-        - debug: (bool)
-        - filename: output html filename (str)
+        HTML: Path to HTML file
+        CSS: Path to CSS file
+        JS: Path to JS file
+        onefile: Only keep output file (bool)
+        debug: (bool)
+        filename: output html filename (str)
+        remove_webfiles: delete 'webfiles' dir
 
         DESCRIPTION
 
@@ -741,6 +742,12 @@ def merge_html(HTML: Path, CSS: Path, JS: Path, onefile: bool=False, debug: bool
             if not directory == fs.root():
               shutil.rmtree(directory)
 
+        ## REMOVE WEBFILES DIR IF REMOVE_WEBFILES == ENABLED
+        if remove_webfiles:
+          if fs.path_exists(f"{directory}/webfiles"):
+            shutil.rmtree(f"{directory}/webfiles")
+
+        ## DEBUG: PRINT COMPLETION MESSAGE
         if debug:
             return print(f"\n{HTML}\n"
                             f"{CSS}\n"
@@ -761,18 +768,32 @@ def network_test():
             network_connectivity_test.close()
 
 ## READS FILE EXTENSIONS
-def read_format(Input: str, Include_Period: bool=False, Print: bool=False):
-  if Include_Period:
-    file_format = f".{Input.split('.')[-1].upper()}"
-  else:
-    file_format = Input.split('.')[-1].upper()
-  if '?' in file_format:
-    file_format = file_format.split('?')[0]
-  if '/' in file_format:
-    file_format = file_format.split('/')[0]
-  if Print:
-    print(file_format)
-  return file_format
+def read_format(Input: str, Include_Period: bool=False, Print: bool=False, Uppercase: bool=False):
+    
+    ## INCLUDE PERIOD IN FORMAT
+    if Include_Period:
+        file_format = f".{Input.split('.')[-1]}"
+    
+    ## RETURN FORMAT WITHOUT PERIOD
+    else:
+        file_format = Input.split('.')[-1]
+
+    ## CLEAR SPECIAL CHARACTERS
+    if '?' in file_format:
+        file_format = file_format.split('?')[0]
+    if '/' in file_format:
+        file_format = file_format.split('/')[0]
+    
+    ## IF UPPERCASE == ENABLED
+    if Uppercase:
+        file_format = file_format.upper()
+
+    ## PRINT FORMAT TO TERMINAL
+    if Print:
+        print(file_format)
+
+    ## RETURN FORMAT
+    return file_format
 
 ## STRIP HTML TAGS FROM STRING
 def strip_tags(Input: str):
